Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1091)

Unified Diff: editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener_OLD.java

Issue 554143003: Integrate the EXTRACT_METHOD refactoring into Editor. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener_OLD.java
diff --git a/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener.java b/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener_OLD.java
similarity index 93%
rename from editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener.java
rename to editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener_OLD.java
index 32d8a55cc3a3fc9e9e3e86ef237f4d98e9485f2a..98fdf7c6b524dbb34738d38f396727e10f3bb88b 100644
--- a/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener.java
+++ b/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/IParameterListChangeListener_OLD.java
@@ -18,12 +18,12 @@ import com.google.dart.engine.services.refactoring.Parameter;
/**
* @coverage dart.editor.ui.refactoring.ui
*/
-public interface IParameterListChangeListener {
+public interface IParameterListChangeListener_OLD {
/**
* Empty implementation of {@link IParameterListChangeListener}.
*/
- class Empty implements IParameterListChangeListener {
+ class Empty implements IParameterListChangeListener_OLD {
@Override
public void parameterAdded(Parameter parameter) {
}
@@ -18,12 +18,12 @@ import com.google.dart.engine.services.refactoring.Parameter;
/**
- * Empty implementation of {@link IParameterListChangeListener}.
+ * Empty implementation of {@link IParameterListChangeListener_OLD}.
*/

Powered by Google App Engine
This is Rietveld 408576698